"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DynamoDBSessionStorage = void 0;
var tslib_1 = require("tslib");
var client_dynamodb_1 = require("@aws-sdk/client-dynamodb");
var util_dynamodb_1 = require("@aws-sdk/util-dynamodb");
var shopify_api_1 = require("@shopify/shopify-api");
var defaultDynamoDBSessionStorageOptions = {
    sessionTableName: 'shopify_sessions',
    shopIndexName: 'shop_index',
};
var DynamoDBSessionStorage = /** @class */ (function () {
    function DynamoDBSessionStorage(opts) {
        this.options = tslib_1.__assign(tslib_1.__assign({}, defaultDynamoDBSessionStorageOptions), opts);
        this.client = new client_dynamodb_1.DynamoDBClient(tslib_1.__assign({}, this.options.config));
    }
    DynamoDBSessionStorage.prototype.storeSession = function (session) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.client.send(new client_dynamodb_1.PutItemCommand({
                            TableName: this.options.sessionTableName,
                            Item: this.serializeSession(session),
                        }))];
                    case 1:
                        _a.sent();
                        return [2 /*return*/, true];
                }
            });
        });
    };
    DynamoDBSessionStorage.prototype.loadSession = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var result;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!id)
                            return [2 /*return*/, undefined];
                        return [4 /*yield*/, this.client.send(new client_dynamodb_1.GetItemCommand({
                                TableName: this.options.sessionTableName,
                                Key: this.serializeId(id),
                            }))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result.Item ? this.deserializeSession(result.Item) : undefined];
                }
            });
        });
    };
    DynamoDBSessionStorage.prototype.deleteSession = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.client.send(new client_dynamodb_1.DeleteItemCommand({
                            TableName: this.options.sessionTableName,
                            Key: this.serializeId(id),
                        }))];
                    case 1:
                        _a.sent();
                        return [2 /*return*/, true];
                }
            });
        });
    };
    DynamoDBSessionStorage.prototype.deleteSessions = function (ids) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, Promise.all(ids.map(function (id) { return _this.deleteSession(id); }))];
                    case 1:
                        _a.sent();
                        return [2 /*return*/, true];
                }
            });
        });
    };
    DynamoDBSessionStorage.prototype.findSessionsByShop = function (shop) {
        var _a;
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var result, sessions;
            var _this = this;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0: return [4 /*yield*/, this.client.send(new client_dynamodb_1.QueryCommand({
                            TableName: this.options.sessionTableName,
                            IndexName: this.options.shopIndexName,
                            KeyConditionExpression: 'shop = :shop',
                            ExpressionAttributeValues: (0, util_dynamodb_1.marshall)({
                                ':shop': shop,
                            }),
                            ProjectionExpression: 'id, shop',
                        }))];
                    case 1:
                        result = _b.sent();
                        return [4 /*yield*/, Promise.all(((_a = result.Items) === null || _a === void 0 ? void 0 : _a.map(function (item) { return _this.loadSession(_this.deserializeId(item)); })) ||
                                [])];
                    case 2:
                        sessions = _b.sent();
                        return [2 /*return*/, sessions.filter(function (session) { return session !== undefined; })];
                }
            });
        });
    };
    DynamoDBSessionStorage.prototype.serializeId = function (id) {
        return (0, util_dynamodb_1.marshall)({ id: id });
    };
    DynamoDBSessionStorage.prototype.deserializeId = function (id) {
        return (0, util_dynamodb_1.unmarshall)(id).id;
    };
    DynamoDBSessionStorage.prototype.serializeSession = function (session) {
        var _a;
        // DynamoDB doesn't support Date objects, so we need to convert it to an ISO string
        var rawSession = tslib_1.__assign(tslib_1.__assign({}, session.toObject()), { expires: (_a = session.expires) === null || _a === void 0 ? void 0 : _a.toISOString() });
        return (0, util_dynamodb_1.marshall)(rawSession, {
            removeUndefinedValues: true,
        });
    };
    DynamoDBSessionStorage.prototype.deserializeSession = function (session) {
        var rawSession = (0, util_dynamodb_1.unmarshall)(session);
        // Convert the ISO string back to a Date object
        return new shopify_api_1.Session(tslib_1.__assign(tslib_1.__assign({}, rawSession), { expires: rawSession.expires ? new Date(rawSession.expires) : undefined }));
    };
    return DynamoDBSessionStorage;
}());
exports.DynamoDBSessionStorage = DynamoDBSessionStorage;
//# sourceMappingURL=dynamodb.js.map